
import os
import subprocess
import sys

from distutils.core import setup, Extension

from pybind11.setup_helpers import Pybind11Extension, build_ext # noqa: E402

try:
    INCLUDE_DIRS = subprocess.getoutput('pybind11-config --include')
except Exception as e:
    print("Error while executing pybind11-config ('{}').\npybind11 probably not installed?".format(str(e)))
    sys.exit(1)

pf = sys.platform
if pf.startswith("win32"):
    LIBS = ["ws2_32"]
elif pf.startswith('linux'):
    LIBS = ["pthread", "rt"]
else:
    raise RuntimeError("Platform '{}' currently not supported.".format(pf))


os.environ ["CFLAGS"] = ''

PKG_NAME = "eth_booster"
EXT_NAMES = ['eth_booster']
__version__ = "0.0.1"

ext_modules = [
    Pybind11Extension(
        EXT_NAMES[0],
        include_dirs = [INCLUDE_DIRS],
        sources = ["blocking_socket.cpp", "utils.cpp", "wrap.cpp"],
        define_macros = [('EXTENSION_NAME', EXT_NAMES[0])],
        extra_compile_args = ['-O3', '-Wall', '-Weffc++', '-std=c++17'],
        libraries = LIBS,
    ),
]

setup(
    name = PKG_NAME,
    version = "0.0.1",
    author = "Christoph Schueler",
    description = "Example",
    ext_modules = ext_modules,
    cmdclass = {"build_ext": build_ext},
)




#!/usr/bin/env python
# -*- coding: utf-8 -*-

import socket
import eth_booster as eth

#print(dir(eth))

print(eth.hello_v())

print(eth.mapped({0: "world!!!"}))
print(eth.mapped({0: 2}))

bs = eth.Socket(socket.AF_INET, socket.SOCK_STREAM, socket.IPPROTO_TCP)
address = eth.CAddress()
bs.getaddrinfo(socket.AF_INET, socket.SOCK_STREAM, socket.IPPROTO_TCP, "192.168.168.100", 50007, address, 0);
bs.connect(address)
print(bs.rcv_buffer_size, bs.reuse_addr, bs.send_buffer_size)

#help(bs)


def main():
    pass

if __name__ == '__main__':
    main()





import os
import subprocess

from distutils.core import setup, Extension

from pybind11.setup_helpers import Pybind11Extension, build_ext, ParallelCompile, naive_recompile

#ParallelCompile("NPY_NUM_BUILD_JOBS").install()
ParallelCompile("NPY_NUM_BUILD_JOBS", needs_recompile=naive_recompile).install()

INCLUDE_DIRS = subprocess.getoutput('pybind11-config --include')

#os.environ ["CFLAGS"] = ''

PKG_NAME = "rekorder_test"
EXT_NAMES = ['rekorder']
__version__ = "0.0.1"

ext_modules = [
    Pybind11Extension(
        EXT_NAMES[0],
        include_dirs = [INCLUDE_DIRS],
        sources = ["lz4.c", "wrap.cpp"],
        define_macros = [('EXTENSION_NAME', EXT_NAMES[0])],
        extra_compile_args = ['-O3', '-std=c++17'],
    ),
]

setup(
    name = PKG_NAME,
    version = "0.0.1",
    author = "John Doe",
    description = "Example",
    ext_modules = ext_modules,
    cmdclass = {"build_ext": build_ext},
)




from pyxcp.master import Master
from pyxcp.types import AddressGranularity, XcpResponseError, XcpTimeoutError

import pyxcp

import pyxcp.transport.candriver
from pyxcp.transport.candriver.pc_socketcan import SocketCAN


cfg = {
    "TRANSPORT": "CAN",
    "CAN_DRIVER": "SocketCAN",
    "CAN_USE_DEFAULT_LISTENER": True,
    "CHANNEL": "vcan0",
    "CAN_ID_MASTER": 2045,
    "CAN_ID_SLAVE": 2046,
    "MAX_DLC_REQUIRED": False,
    "CREATE_DAQ_TIMESTAMPS": False,
    "FD": False
}

master = Master("Can", cfg)

print(master.connect())
print(master.getCommModeInfo())

result = master.getId(0x01)
if int(result.mode) == 1:
    name = bytes(result.identification).decode("ascii")
else:
    if result.length:
        name = bytes(master.upload(result.length)).decode("ascii")
    else:
        name = "<unknown>"

print(name)




#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Very basic hello-world example.
"""

__copyright__ = """
    pySART - Simplified AUTOSAR-Toolkit for Python.

   (C) 2009-2019 by Christoph Schueler <cpu12.gems@googlemail.com>

   All Rights Reserved

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""



from pprint import pprint

from pyxcp.cmdline import ArgumentParser

def callout(master, args):
    if args.sk_dll:
        master.seedNKeyDLL = args.sk_dll

ap = ArgumentParser(callout)
ap.parser.add_argument("-s", "--sk-dll", dest = "sk_dll", help = "Seed-and-Key .DLL name", type = str, default = None)


with ap.run() as x:
    x.connect()
    if x.slaveProperties.optionalCommMode:
        x.getCommModeInfo()
    #gid = x.getId(0x1)
    try:
        gid = x.getId(0xdc)
    except Exception as e:
        print(str(e))
    else:
        result = x.fetch(gid.length)
        print(result)
    x.getStatus()
    x.synch()
    x.cond_unlock()
    daqInfo = x.getDaqInfo()
    print(x.getDaqClock())
    x.disconnect()
    print("\nSlave properties")
    print("================")
    print("ID: '{}'".format(result.decode("utf8")))
    pprint(x.slaveProperties)
    print("\nDAQ Properties")
    print("==============")
    pprint(daqInfo)
